//
// Shige-Fuji Project
// SwiftUI Archives
//
// Copyright (c) Watanabe-Denki, Inc.
//   https://wdkk.co.jp/
//
// This software is released under the MIT License.
//   https://opensource.org/licenses/mit-license.php
//

import UIKit
import RealityKit

class CustomARView: ARView {    
    // アンカー
    var firstAnchor: AnchorEntity = AnchorEntity()
 
    required init(frame frameRect: CGRect) {
        super.init(frame: frameRect)
        createScene()
    }
    
    @MainActor required dynamic init?(coder decoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    func prepareAnchor() {
        // 検出無しに設置するアンカー
        firstAnchor.position = simd_make_float3(0.0, -0.5, -1.0) // アンカーの位置は、デバイス初期位置から0.5m下、1m奥（ARKitでは1m = 1.0）
        self.scene.anchors.append(firstAnchor)   // CustomARView(self)にアンカーを追加
    }
    
    func createScene() {
        // アンカーの準備
        prepareAnchor()
        
        // UnlitMaterial: 物理演算無しのマテリアル（ライティングとシェーディングをしない）
        let unlit_material = UnlitMaterial(color: .orange)
         
        // 立方体を作成
        let box_unlit = ModelEntity(mesh: .generateBox(size: simd_make_float3(0.3, 0.3, 0.3)))
        box_unlit.model?.materials = [unlit_material]
        box_unlit.transform = Transform(translation: simd_make_float3(0.0, 0.2, 0.2))
        self.firstAnchor.addChild(box_unlit)    // アンカーに追加
    }
}

